@@ -10,7 +10,7 @@
 
 #define PODOFO_VERSION_MAJOR 0
 #define PODOFO_VERSION_MINOR 9
-#define PODOFO_VERSION_PATCH 5
+#define PODOFO_VERSION_PATCH 6
 
 /* PoDoFo configuration options */
 #define PODOFO_MULTI_THREAD
@@ -38,7 +38,7 @@
 
 /* Sizes of int64 and long, to pick proper printf format */
 #define SZ_INT64 8
-#define SZ_LONG 8
+#define SZ_LONG 4
 
 /* Endianness */
 /* #undef TEST_BIG */
@@ -55,5 +55,7 @@
 /* #undef PODOFO_HAVE_BOOST */
 #define PODOFO_HAVE_CPPUNIT
 #define PODOFO_HAVE_OPENSSL
-/* #undef PODOFO_HAVE_OPENSSL_1_1 */
+#define PODOFO_HAVE_OPENSSL_1_1
+/* #undef PODOFO_HAVE_OPENSSL_NO_RC4 */
 #define PODOFO_HAVE_LIBIDN
+#define PODOFO_HAVE_UNISTRING_LIB
